@@ -49,7 +49,7 @@ class Context:
 		if self.timing:
 			starttime = time.time()
 		if self.cmd_func.func_code.co_argcount == 3:
-			# A function with 3 args : self, context, message
+			# A function with 3 args : self, context, command_args
 			ret = self.cmd_func(self, self.command_args)
 		else:
 			ret = self.cmd_func(self)
@@ -61,7 +61,7 @@ class Context:
 				self.say(" ; ".join(ret))
 			elif self.cmd_func.returns == "dic":
 				for item in ret.items():
-					self.say(str(item[0]) + " => " + str(item[1]))
+					self.say("%s => %s" % (item[0], item[1]))
 		self.grep = ""
 		if self.timing:
 			diff = time.time() - starttime
@@ -71,6 +71,13 @@ class Context:
 				self.say ("%s secondes..." % str(diff) )
 		
 	def launch (self):
+		if hasattr(self.cmd_func, "conflict_with"):
+			try:
+				assert not(self.bot.threads[self.cmd_func.conflict_with]._Thread__stopped)
+				self.say ("Conflicting with thread %s" % self.cmd_func.conflict_with)
+				return
+			except:
+				pass
 		if hasattr(self.cmd_func, "threaded"):
 			print self.bot.threads
 			try:
