@@ -20,7 +20,7 @@ import xml.sax
 
 class IRCConf (xml.sax.handler.ContentHandler):
 	def __init__ (self, filename):
-		for attr in ["nick", "url", "channel", "versionNum", "versionEnv", "versionName", "ident", "realname", "rights"]:
+		for attr in ["nick", "url", "channel", "versionNum", "versionEnv", "versionName", "ident", "realname", "rights", "charset"]:
 			setattr(self, attr, "")
 		self.port = 0
 		self.currentPath = ""
@@ -45,7 +45,7 @@ class IRCConf (xml.sax.handler.ContentHandler):
 		else:
 			self.currentPath += "/" + name
 		if name == "bot":
-			for attr in ["nick", "ident", "realname", "rights"]:
+			for attr in ["nick", "ident", "realname", "rights", "charset"]:
 				if attributes.has_key(attr):
 					setattr(self, attr, str(attributes[attr]))
 		elif name == "version":
