@@ -37,4 +37,17 @@ def threaded (func):
 
 def accept_list (func):
 	func.accept_list = True
-	return func
\ No newline at end of file
+	return func
+
+def conflict_with (conflict):
+	def wrapper (func):
+		func.conflict_with = conflict
+		return func
+	return wrapper
+
+def core_hook (hookname):
+	def wrapper (func):
+		func.is_hook = True
+		func.hook_name = hookname
+		return func
+	return wrapper
