@@ -70,11 +70,11 @@ class adminLogic(base_logic.Base):
 	def Call_reload_config (self, context):
 		self.core.config.parse()
 		context.say("Config reloaded")
-		context.say(self.core.config.rights)
 
 	@admin
 	def Call_reload_rights (self, context):
 		if self.core.rights.config == self.core.config.rights:
+			# The parse() fonction of the rightsManager is doing the job for us...
 			self.core.rights.parse()
 		else:
 			self.core.rights.close()
@@ -88,13 +88,17 @@ class adminLogic(base_logic.Base):
 		else:
 			context.say ("You can't be logged in !")
 	
-	def leftevent (self, channel, args):
-		if self.core.rights.logged_in(args[0]):
-			self.core.rights.logout(args[0])
+	def leftevent (self, channel, user, chan):
+		if self.core.rights.logged_in(user):
+			self.core.rights.logout(user)
+	
+	def kickevent (self, channel, user, chan, kicker, reason):
+		if self.core.rights.logged_in(user):
+			self.core.rights.logout(user)
 		
-	def renameevent (self, channel, args):
-		if self.core.rights.logged_in(args[0]):
-			self.core.rights.logout(args[0])
+	def renameevent (self, oldname, newname):
+		if self.core.rights.logged_in(oldname):
+			self.core.rights.logout(oldname)
 	
 	def Call_logout (self, context):
 		if self.core.rights.logout (context.user):
