@@ -24,8 +24,7 @@ class todoLogic(base_logic.Base):
 		base_logic.Base.__init__(self, core)
 		self.persistant["todos"] = [] #Contains tuples (user, message)
 		
-	def joinevent (self, channel, args):
-		user = args[0][:args[0].find("!")]
+	def joinevent (self, user, channel):
 		for todo in self.persistant["todos"]:
 			if todo[0] == user:
 				self.bot.notice(user, "TODO :" + todo[1])
