@@ -39,7 +39,7 @@ class RightsManager:
 	
 	def has_right (self, user, right):
 		try:
-			return self.plugin.has_right(user.lower().split('!', 1)[0], right)
+			return self.plugin.has_right(user, right)
 		except:
 			infos = sys.exc_info()
 			sys.excepthook(infos[0], infos[1], infos[2])
@@ -47,7 +47,6 @@ class RightsManager:
 			return False
 	
 	def is_core_admin (self, user):
-		user = user.lower().split('!', 1)[0]
 		try:
 			return self.plugin.is_core_admin(user)
 		except:
@@ -58,7 +57,7 @@ class RightsManager:
 	
 	def is_admin (self, user):
 		try:
-			return self.plugin.is_admin(user.lower().split('!', 1)[0])
+			return self.plugin.is_admin(user)
 		except:
 			infos = sys.exc_info()
 			sys.excepthook(infos[0], infos[1], infos[2])
@@ -67,7 +66,6 @@ class RightsManager:
 	
 	def login (self, user, passwd):
 		try:
-			user = user.lower().split('!', 1)[0]
 			if self.plugin.check_passwd(user, passwd):
 				self.logins[user] = time.time() + 240
 				return True
@@ -80,7 +78,6 @@ class RightsManager:
 			return False
 	
 	def logged_in (self, user):
-		user = user.lower().split('!', 1)[0]
 		if self.logins.has_key(user):
 			if self.logins[user] > time.time():
 				return True
@@ -89,7 +86,6 @@ class RightsManager:
 		return False
 	
 	def logout (self, user):
-		user = user.lower().split('!', 1)[0]
 		if self.logged_in (user):
 			del self.logins[user]
 			return True
